rf_property {#master}
-------------------------

## Important Changes

### yarp::os

#### Property
* `yarp::os::property` class now implements the new tag `import <contextname> <filename>` which allows to include .ini configuration files belonging to different contexts

